NPExtractor
===========

.. currentmodule:: lexnlp.extract.en.utils

.. autoclass:: NPExtractor
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~NPExtractor.exception_pos
      ~NPExtractor.exception_sym
      ~NPExtractor.sym_with_space
      ~NPExtractor.sym_without_space

   .. rubric:: Methods Summary

   .. autosummary::

      ~NPExtractor.cleanup_leaves
      ~NPExtractor.get_np
      ~NPExtractor.get_tokenizer
      ~NPExtractor.join
      ~NPExtractor.sep
      ~NPExtractor.strip_np

   .. rubric:: Attributes Documentation

   .. autoattribute:: exception_pos
   .. autoattribute:: exception_sym
   .. autoattribute:: sym_with_space
   .. autoattribute:: sym_without_space

   .. rubric:: Methods Documentation

   .. automethod:: cleanup_leaves
   .. automethod:: get_np
   .. automethod:: get_tokenizer
   .. automethod:: join
   .. automethod:: sep
   .. automethod:: strip_np
